import {getCars} from './getCars';
import {colorLegend} from './colorLegend';
import {loadAndProcessData,parseYear} from './loadAndProcessData';

import {generateReport} from './generateReport';
import {lineChart} from './lineChart';

import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleTime,
  line,
  nest,
  curveBasis,
  scaleOrdinal,
  schemeCategory10,//pre zaoblovanie ciary
  descending,
  mouse
	} from 'd3' //importujeme potrebne fcie z d3
const svg=select('svg');
const width=+svg.attr('width');
const height=+svg.attr('height');
const  colorLegendG=svg.append('g');
const  lineChartG=svg.append('g');



let selectedYear=2018;
const colorValue=d=>d.country;
let data;
const setSelectedYear=year=>{
  selectedYear=year;
  render();
}

const render = () =>{
   const yValue=d=>d.population;
  const colorScale= scaleOrdinal(schemeCategory10);
  const lastYValue=d=>yValue(d.values[d.values.length-1]);
 
  const nested= nest()
    .key(colorValue) //kluc podla ktoreho kuskujeme - mesta
    .entries(data) //data kt chceme rozkuskovat
     .sort((a,b)=>
    descending(lastYValue(a),lastYValue(b)));
  colorScale.domain(nested.map(d=>d.key));
   
 lineChartG.call(lineChart, {
    colorScale,
    colorValue,
    yValue,
    title: 'Population over Time by Region',
    xValue: d => d.year,
    xAxisLabel: 'Time',
    circleRadius: 6,
    yAxisLabel: 'Population',
    margin: {
      top: 60,
      right: 280,
      bottom: 88,
      left: 105
    },
    width,
    height,
    data,
    nested,
   selectedYear,
   setSelectedYear
  });
  
  colorLegendG
  .attr('transform',`translate(740,100)`)
  .call(colorLegend,{
           colorScale,
           circleRadius:15,
           spacing:35,
           textOffset:20
           });
  
  

};
 

loadAndProcessData().then( (loadedData)=>{
		data=loadedData;
    render();

});





